DeclaredPassiveEffectOverride

Struct DeclaredPassiveEffectOverride 

pub struct DeclaredPassiveEffectOverride {
    pub spell_id: u32,
    pub effect: u8,
    pub source: Option<(u32, u8)>,
    pub value: f64,
    pub multiplier: f64,
}
The replacement value one passive effect really applies at, as register_passive_effect_override.

The result is the source effect’s post-rescale value times multiplier. With no source named it is value times multiplier instead.

Fields

spell_id: u32effect: u8source: Option<(u32, u8)>value: f64multiplier: f64